@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 
 import datetime
@@ -24,7 +24,7 @@ class CuJiraX:
         self.testexecution_desc = None
         self.parent_testset_key = parent_testset_key
 
-    def set_testexcution(self, jira_key: str):
+    def set_testexecution(self, jira_key: str):
         self.testexecution = Jirakey(jira_key)
 
     def set_testexecution_name(self, testexecution_name: str):
